@@ -1,8 +1,6 @@
 import time, pyperclip
 from kivy import Config
 import os, darkdetect, threading
-from kivymd.uix.button import MDFlatButton
-from kivymd.uix.picker import MDDatePicker
 
 Config.set('graphics', 'resizable', 0)
 Config.set('input', 'mouse', 'mouse, multitouch_on_demand')
@@ -15,15 +13,10 @@ from kivy.uix.settings import ContentPanel
 from kivymd.app import MDApp
 from screeninfo import get_monitors
 from kivy.properties import *
-from kivymd.uix.snackbar import Snackbar
-from kivymd.toast import toast
-from kivymd.icon_definitions import md_icons
-from kivymd.uix.list import IconLeftWidget, TwoLineAvatarIconListItem, IconRightWidget
-from kivymd.uix.list import OneLineAvatarIconListItem
-
 
 
 def icons(f: str = ''):
+    from kivymd.icon_definitions import md_icons
     print([x for x in list(md_icons.keys()) if f in x])
 
 
@@ -124,7 +117,8 @@ class Kivy4(MDApp):
             self.sun_icon = sun_icon
             self.isDarkMode()
 
-        self.setProperties(main_color, disable_x, icon, toolbar, string, pre_string)
+        self.setProperties(main_color, icon, toolbar, string, pre_string)
+        self.disable_x = disable_x
 
         screen = get_monitors()[0]
         self.width = screen.width
@@ -134,10 +128,10 @@ class Kivy4(MDApp):
 
         self.run()
 
-    def setProperties(self, main_color, disable_x, icon, toolbar, string, pre_string):
+    def setProperties(self, main_color, icon, toolbar, string, pre_string):
 
         for x in pre_string.split('\n'):
-            if 'x,y=' in x.replace(' ', ''):
+            if 'x,y=' in x.replace(' ', '') and '#' not in x:
                 self.builder_string += '\n' + self.x_y(x)
 
             else:
@@ -149,14 +143,13 @@ class Kivy4(MDApp):
             self.builder_string += self.getToolbar(toolbar)
 
             for x in string.split('\n'):
-                if 'x,y=' in x.replace(' ', ''):
+                if 'x,y=' in x.replace(' ', '') and '#' not in x:
                     self.builder_string += '\n            ' + self.x_y(x)
 
                 else:
                     self.builder_string += '\n            ' + x
 
         self.theme_cls.primary_palette = main_color
-        self.disable_x = disable_x
         self.icon = icon
 
     def build(self):
@@ -341,10 +334,15 @@ Screen:
 
     @staticmethod
     def toast(text, duration=2.5):
+        from kivymd.toast import toast
+
         toast(text=text, duration=duration)
 
     @staticmethod
     def snack(text, button_text=None, func=None):
+        from kivymd.uix.button import MDFlatButton
+        from kivymd.uix.snackbar import Snackbar
+
         snack = Snackbar(text=text)
 
         if func and button_text:
@@ -402,6 +400,7 @@ Screen:
         pyperclip.copy(text)
 
     def show_date_picker(self, on_save, mode='picker'):
+        from kivymd.uix.picker import MDDatePicker
         date_dialog = MDDatePicker(mode=mode)
         date_dialog.bind(on_save=on_save, on_cancel=self.on_cancel_picker)
         date_dialog.open()
